import type { PropDefinitions, RemoteEvent, Sheet, RemoteElement } from './types';
import type { Tree } from './worker/tree';
export declare const DEFINE = "fritz:define";
export declare const TRIGGER = "fritz:trigger";
export declare const RENDER = "fritz:render";
export declare const EVENT = "fritz:event";
export declare const STATE = "fritz:state";
export declare const DESTROY = "fritz:destroy";
export declare const RENDERED = "fritz:rendered";
export declare const CLEANUP = "fritz:cleanup";
export type WindowRenderMessage = {
    type: typeof RENDER;
    tag: string;
    id: number;
    props: Record<string, any>;
};
export type EventMessage = {
    type: typeof EVENT;
    event: {
        type: string;
        detail: any;
        value: string;
    };
    id: number;
    handle: number | undefined;
};
export type StateMessage = {
    type: typeof STATE;
    state: any;
};
export type DestroyMessage = {
    type: typeof DESTROY;
    id: number;
};
export type RenderedMessage = {
    type: typeof RENDERED;
    id: number;
};
export type CleanupMessage = {
    type: typeof CLEANUP;
    id: number;
    handles: Array<number>;
};
export type MessageSentFromWindow = WindowRenderMessage | EventMessage | StateMessage | DestroyMessage | RenderedMessage | CleanupMessage;
export type DefineMessage = {
    type: typeof DEFINE;
    tag: string;
    props: PropDefinitions | undefined;
    events: Array<string> | undefined;
    styles: Array<RemoteElement | Sheet> | undefined;
    features: {
        mount: boolean;
    };
};
export type TriggerMessage = {
    type: typeof TRIGGER;
    event: RemoteEvent;
    id: number;
};
export type WorkerRenderMessage = {
    type: typeof RENDER;
    id: number;
    tree: Tree;
};
export type MessageSentFromWorker = DefineMessage | TriggerMessage | WorkerRenderMessage;
